@@ -3,7 +3,6 @@
 bayestestR::equivalence_test
 
 
-
 #' @title Equivalence test
 #'
 #' @description Compute the (conditional) equivalence test for frequentist models.
@@ -15,9 +14,6 @@ bayestestR::equivalence_test
 #' @param ci Confidence Interval (CI) level. Default to `0.95` (`95%`).
 #' @param rule Character, indicating the rules when testing for practical
 #' equivalence. Can be `"bayes"`, `"classic"` or `"cet"`. See 'Details'.
-#' @param test Hypothesis test for computing contrasts or pairwise comparisons.
-#' See [`?ggeffects::test_predictions`](https://strengejacke.github.io/ggeffects/reference/test_predictions.html)
-#' for details.
 #' @param verbose Toggle warnings and messages.
 #' @param ... Arguments passed to or from other methods.
 #' @inheritParams model_parameters.glmmTMB
@@ -268,7 +264,6 @@ equivalence_test.lm <- function(x,
 }
 
 
-
 # standard models, only fixed effects ----------------------
 
 #' @export
@@ -305,9 +300,6 @@ equivalence_test.zeroinfl <- equivalence_test.lm
 equivalence_test.rma <- equivalence_test.lm
 
 
-
-
-
 # mixed models, also random effects ----------------------
 
 #' @export
@@ -363,7 +355,6 @@ equivalence_test.glmmTMB <- equivalence_test.merMod
 equivalence_test.MixMod <- equivalence_test.merMod
 
 
-
 # Special classes -------------------------
 
 #' @export
@@ -411,86 +402,6 @@ equivalence_test.parameters_model <- function(x,
 }
 
 
-#' @rdname equivalence_test.lm
-#' @export
-equivalence_test.ggeffects <- function(x,
-                                       range = "default",
-                                       rule = "classic",
-                                       test = "pairwise",
-                                       verbose = TRUE,
-                                       ...) {
-  insight::check_if_installed("ggeffects")
-
-  # get attributes from ggeffects objects, so we have the original model and terms
-  focal <- attributes(x)$original.terms
-  obj_name <- attributes(x)$model.name
-  ci <- attributes(x)$ci.lvl
-  dof <- attributes(x)$df
-
-  x <- .get_ggeffects_model(x)
-
-  # validation check rope range
-  rule <- match.arg(tolower(rule), choices = c("bayes", "classic", "cet"))
-  range <- .check_rope_range(x, range, verbose)
-
-  out <- ggeffects::test_predictions(
-    x,
-    terms = focal,
-    test = test,
-    equivalence = range,
-    verbose = verbose,
-    ...
-  )
-
-  out <- insight::standardize_names(out)
-
-  # we only have one type of CIs
-  conf_int <- conf_int2 <- as.data.frame(t(out[c("CI_low", "CI_high")]))
-
-  l <- Map(
-    function(ci_wide, ci_narrow) {
-      .equivalence_test_numeric(
-        ci = ci,
-        ci_wide,
-        ci_narrow,
-        range_rope = range,
-        rule = rule,
-        dof = dof,
-        verbose = verbose
-      )
-    }, conf_int, conf_int2
-  )
-
-  # bind to data frame
-  dat <- do.call(rbind, l)
-
-  # remove old CIs, bind results from equivalence test
-  out$CI_low <- out$CI_high <- NULL
-  out$CI <- ci
-  out <- cbind(out, dat)
-
-  # standardize column order
-  cols <- c(
-    "Estimate", "Contrast", "Slope", "Predicted", "CI", "CI_low", "CI_high",
-    "SGPV", "ROPE_low", "ROPE_high", "ROPE_Percentage", "ROPE_Equivalence", "p"
-  )
-
-  # order of shared columns
-  shared_order <- intersect(cols, colnames(out))
-  parameter_columns <- setdiff(colnames(out), shared_order)
-  # add remaining columns, sort
-  out <- out[c(parameter_columns, shared_order)]
-
-  attr(out, "object_name") <- obj_name
-  attr(out, "parameter_columns") <- parameter_columns
-  attr(out, "rule") <- rule
-  attr(out, "rope") <- range
-  class(out) <- c("equivalence_test_lm", "see_equivalence_test_ggeffects", "data.frame")
-  out
-}
-
-
-
 # helper -------------------
 
 
@@ -590,7 +501,6 @@ equivalence_test.ggeffects <- function(x,
 }
 
 
-
 #' @keywords internal
 .equivalence_test_frequentist_random <- function(x,
                                                  range = "default",
@@ -667,8 +577,6 @@ equivalence_test.ggeffects <- function(x,
 }
 
 
-
-
 #' @keywords internal
 .equivalence_test_numeric <- function(ci = 0.95,
                                       ci_wide,
@@ -736,8 +644,6 @@ equivalence_test.ggeffects <- function(x,
 }
 
 
-
-
 # helper ---------------------
 
 # this function simply takes the length of the range and calculates the proportion
@@ -849,14 +755,9 @@ equivalence_test.ggeffects <- function(x,
 }
 
 
-
-
-
-
 # methods ----------------
 
 
-
 #' @export
 format.equivalence_test_lm <- function(x,
                                        digits = 2,
@@ -899,7 +800,6 @@ format.equivalence_test_lm <- function(x,
 }
 
 
-
 #' @export
 print.equivalence_test_lm <- function(x,
                                       digits = 2,
