@@ -689,31 +689,8 @@ as.data.frame.VarCorr.lme <- function(x, row.names = NULL, optional = FALSE, ...
 # store essential information about variance components...
 # basically, this function should return lme4::VarCorr(x)
 .get_variance_information <- function(model, model_component = "conditional") {
-  # reason to be installed
-  reason <- "to compute random effect variances for mixed models"
-
-  # installed?
-  insight::check_if_installed("lme4", reason = reason)
-
-  if (inherits(model, "lme")) {
-    insight::check_if_installed("nlme", reason = reason)
-  }
-
-  if (inherits(model, "clmm")) {
-    insight::check_if_installed("ordinal", reason = reason)
-  }
-
-  if (inherits(model, "brmsfit")) {
-    insight::check_if_installed("brms", reason = reason)
-  }
-
-  if (inherits(model, "cpglmm")) {
-    insight::check_if_installed("cplm", reason = reason)
-  }
-
-  if (inherits(model, "rstanarm")) {
-    insight::check_if_installed("rstanarm", reason = reason)
-  }
+  # check if packages are available
+  .check_mixedmodels_namespace(model)
 
   # stanreg
   # ---------------------------
@@ -835,6 +812,39 @@ as.data.frame.VarCorr.lme <- function(x, row.names = NULL, optional = FALSE, ...
 }
 
 
+.check_mixedmodels_namespace <- function(model) {
+  # reason to be installed
+  reason <- "to compute random effect variances for mixed models"
+
+  # installed?
+  insight::check_if_installed("lme4", reason = reason)
+
+  if (inherits(model, "lme")) {
+    insight::check_if_installed("nlme", reason = reason)
+  }
+
+  if (inherits(model, "glmmTMB")) {
+    insight::check_if_installed("glmmTMB", reason = reason)
+  }
+
+  if (inherits(model, "clmm")) {
+    insight::check_if_installed("ordinal", reason = reason)
+  }
+
+  if (inherits(model, "brmsfit")) {
+    insight::check_if_installed("brms", reason = reason)
+  }
+
+  if (inherits(model, "cpglmm")) {
+    insight::check_if_installed("cplm", reason = reason)
+  }
+
+  if (inherits(model, "rstanarm")) {
+    insight::check_if_installed("rstanarm", reason = reason)
+  }
+}
+
+
 # glmmTMB returns a list of model information, one for conditional
 # and one for zero-inflation part, so here we "unlist" it, returning
 # only the conditional part.
@@ -856,8 +866,6 @@ as.data.frame.VarCorr.lme <- function(x, row.names = NULL, optional = FALSE, ...
 }
 
 
-
-
 # this is used to only temporarily load merDeriv and to point registered
 # methods from merDeriv to lme4-methods. if merDeriv was loaded before,
 # nothing will be changed. If merDeriv was not loaded, vcov-methods registered
