@@ -4,9 +4,8 @@
 
 #' Parameters from ANOVAs
 #'
-#' @param model Object of class [aov()], [anova()],
-#'   `aovlist`, `Gam`, [manova()], `Anova.mlm`,
-#'   `afex_aov` or `maov`.
+#' @param model Object of class [aov()], [anova()], `aovlist`, `Gam`,
+#'   [manova()], `Anova.mlm`, `afex_aov` or `maov`.
 #' @param es_type The effect size of interest. Not that possibly not all
 #'   effect sizes are applicable to the model object. See 'Details'. For Anova
 #'   models, can also be a character vector with multiple effect size names.
@@ -29,6 +28,8 @@
 #' @param table_wide Logical that decides whether the ANOVA table should be in
 #'   wide format, i.e. should the numerator and denominator degrees of freedom
 #'   be in the same row. Default: `FALSE`.
+#' @param include_intercept Logical, if `TRUE`, includes the intercept
+#'   (`(Intercept)`) in the anova table.
 #' @param alternative A character string specifying the alternative hypothesis;
 #'   Controls the type of CI returned: `"two.sided"` (default, two-sided CI),
 #'   `"greater"` or `"less"` (one-sided CI). Partial matching is allowed
@@ -102,11 +103,13 @@ model_parameters.aov <- function(model,
                                  df_error = NULL,
                                  ci = NULL,
                                  alternative = NULL,
+                                 p_adjust = NULL,
                                  test = NULL,
                                  power = FALSE,
                                  es_type = NULL,
                                  keep = NULL,
                                  drop = NULL,
+                                 include_intercept = FALSE,
                                  table_wide = FALSE,
                                  verbose = TRUE,
                                  ...) {
@@ -138,7 +141,13 @@ model_parameters.aov <- function(model,
   }
 
   # extract standard parameters
-  params <- .extract_parameters_anova(model, test)
+  params <- .extract_parameters_anova(
+    model,
+    test,
+    p_adjust = p_adjust,
+    include_intercept = include_intercept,
+    verbose = verbose
+  )
 
   # add effect sizes, if available
   params <- .effectsizes_for_aov(
@@ -251,6 +260,8 @@ model_parameters.afex_aov <- function(model,
                                       type = NULL,
                                       keep = NULL,
                                       drop = NULL,
+                                      include_intercept = FALSE,
+                                      p_adjust = NULL,
                                       verbose = TRUE,
                                       ...) {
   if (inherits(model$Anova, "Anova.mlm")) {
@@ -258,9 +269,23 @@ model_parameters.afex_aov <- function(model,
     with_df_and_p <- summary(model$Anova)$univariate.tests
     params$`Sum Sq` <- with_df_and_p[-1, 1]
     params$`Error SS` <- with_df_and_p[-1, 3]
-    out <- .extract_parameters_anova(params, test = NULL)
+    out <- .extract_parameters_anova(
+      params,
+      test = NULL,
+      include_intercept = include_intercept,
+      p_adjust = NULL,
+      verbose
+    )
+    p_adjust <- .extract_p_adjust_afex(model, p_adjust)
   } else {
-    out <- .extract_parameters_anova(model$Anova, test = NULL)
+    p_adjust <- .extract_p_adjust_afex(model, p_adjust)
+    out <- .extract_parameters_anova(
+      model$Anova,
+      test = NULL,
+      include_intercept = include_intercept,
+      p_adjust,
+      verbose
+    )
   }
 
   out <- .effectsizes_for_aov(
@@ -273,7 +298,15 @@ model_parameters.afex_aov <- function(model,
   )
 
   # add attributes
-  out <- .add_anova_attributes(out, model, ci, test = NULL, alternative = NULL, ...)
+  out <- .add_anova_attributes(
+    out,
+    model,
+    ci,
+    test = NULL,
+    alternative = NULL,
+    p_adjust = p_adjust,
+    ...
+  )
 
   # filter parameters
   if (!is.null(keep) || !is.null(drop)) {
@@ -532,12 +565,12 @@ model_parameters.seqanova.svyglm <- model_parameters.aov
 .anova_table_wide <- function(data, ...) {
   wide_anova <- function(x) {
     # creating numerator and denominator degrees of freedom
-    idxResid <- x$Parameter == "Residuals"
+    idxResid <- which(x$Parameter == "Residuals")
     if (length(idxResid)) {
       x$df_error <- x$df[idxResid]
       x$Sum_Squares_Error <- x$Sum_Squares[idxResid]
-      x$Mean_Square_Error <- x$Sum_Squares[idxResid]
-      x <- x[!idxResid, ]
+      x$Mean_Square_Error <- x$Mean_Square[idxResid]
+      x <- x[-idxResid, ]
     }
     x
   }
@@ -545,6 +578,12 @@ model_parameters.seqanova.svyglm <- model_parameters.aov
   if ("Group" %in% colnames(data)) {
     data <- split(data, data$Group)
     data <- lapply(data, wide_anova)
+    data <- Filter(function(x) nrow(x) >= 1L, data)
+    cols <- unique(unlist(lapply(data, colnames)))
+    data <- lapply(data, function(x) {
+      x[, setdiff(cols, colnames(x))] <- NA
+      x
+    })
     data <- do.call(rbind, data)
   } else {
     data <- wide_anova(data)
@@ -555,3 +594,17 @@ model_parameters.seqanova.svyglm <- model_parameters.aov
 
   data[, col_order]
 }
+
+
+#' @keywords internal
+.extract_p_adjust_afex <- function(model, p_adjust) {
+  if (is.null(p_adjust) && inherits(model, "afex_aov")) {
+    p_adjust <- attr(model$anova_table, "p_adjust_method")
+
+    if (p_adjust == "none") {
+      p_adjust <- NULL
+    }
+  }
+
+  p_adjust
+}
