@@ -37,7 +37,7 @@
 #'   If `format = "html"`, a `<br>` inserts a line break inside a cell. See
 #'   'Examples'.
 #'
-#' *. **A string indicating a pre-defined layout**
+#' * **A string indicating a pre-defined layout**
 #'
 #'   `select` can be one of the following string values, to create one of the
 #'   following pre-defined column layouts:
@@ -381,6 +381,11 @@ print.parameters_brms_meta <- print.parameters_model
 
 # Random effects ------------------
 
+#' @export
+print.parameters_coef <- function(x, ...) {
+  cat(insight::export_table(format(x, ...), ...))
+}
+
 #' @export
 print.parameters_random <- function(x, digits = 2, ...) {
   .print_random_parameters(x, digits = digits)
@@ -481,11 +486,7 @@ print.parameters_random <- function(x, digits = 2, ...) {
 
   # caption = NULL, set default for HTML tables
   if (identical(format, "html") && is.null(caption)) {
-    if (isTRUE(attributes(x)$is_ggeffects)) {
-      table_caption <- title_attribute
-    } else {
-      table_caption <- "Model Summary"
-    }
+    table_caption <- "Model Summary"
   } else if (isTRUE(attributes(x)$ordinal_model)) {
     table_caption <- ""
 
